summaryrefslogtreecommitdiffstats
path: root/cmake/QtPublicWalkLibsHelpers.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/QtPublicWalkLibsHelpers.cmake')
-rw-r--r--cmake/QtPublicWalkLibsHelpers.cmake13
1 files changed, 7 insertions, 6 deletions
diff --git a/cmake/QtPublicWalkLibsHelpers.cmake b/cmake/QtPublicWalkLibsHelpers.cmake
index 038d5d0625..963c15d4c6 100644
--- a/cmake/QtPublicWalkLibsHelpers.cmake
+++ b/cmake/QtPublicWalkLibsHelpers.cmake
@@ -83,12 +83,13 @@ function(__qt_internal_walk_libs
endif()
list(APPEND collected ${target})
- if(target STREQUAL "${QT_CMAKE_EXPORT_NAMESPACE}::EntryPoint")
- # We can't (and don't need to) process EntryPoint because it brings in $<TARGET_PROPERTY:prop>
- # genexes which get replaced with $<TARGET_PROPERTY:EntryPoint,prop> genexes in the code below
- # and that causes 'INTERFACE_LIBRARY targets may only have whitelisted properties.' errors
- # with CMake versions equal to or lower than 3.18. These errors are super unintuitive to
- # debug because there's no mention that it's happening during a file(GENERATE) call.
+ if(target STREQUAL "${QT_CMAKE_EXPORT_NAMESPACE}::EntryPointPrivate")
+ # We can't (and don't need to) process EntryPointPrivate because it brings in
+ # $<TARGET_PROPERTY:prop> genexes which get replaced with
+ # $<TARGET_PROPERTY:EntryPointPrivate,prop> genexes in the code below and that causes
+ # 'INTERFACE_LIBRARY targets may only have whitelisted properties.' errors with CMake
+ # versions equal to or lower than 3.18. These errors are super unintuitive to debug
+ # because there's no mention that it's happening during a file(GENERATE) call.
return()
endif()